@@ -2,8 +2,9 @@
  * Error handling
  * Library: joedog
  *
- * Copyright (C) 2000 Jeffrey Fulmer <jdfulmer@armstrong.com>
- * This file is part of Siege
+ * Copyright (C) 2000, 2001, 2002 by
+ * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,37 +26,81 @@
 # include <config.h>
 #endif/*HAVE_CONFIG_H*/
 
+#include <stdlib.h>
 #include <stdio.h>
+#include <syslog.h>
 #include <stdarg.h>
-#include "error.h"
+#include <string.h>
+#include <errno.h>
 
 #define BUFSIZE 4096
 
+static void   log_message( int status, const char *mode, const char *fmt, va_list ap );
 static void error_message( int status, const char *mode, const char *fmt, va_list ap );
 
+void
+joe_openlog( char *program )
+{
+  openlog( program, LOG_PID, LOG_DAEMON ); 
+  return;
+}
+
+void 
+joe_closelog( void )
+{
+  closelog();
+  return;
+}
+
 /**
  *  error_message    program centric error message
  */
 void 
-error_message( int status, const char *mode, const char *fmt, va_list ap )
+log_message( int status, const char *mode, const char *fmt, va_list ap )
 {
   char buf[BUFSIZE];
-  int  err = 4; 
-  
-  vsprintf( buf, fmt, ap );
-  sprintf( buf + strlen( buf ), ": %s\n", strerror(err));
-  fflush( stdout );
-  if( status >= 0 ){ exit( status ); }
 
-  fprintf( stderr, "%s: %s", mode, buf );
+
+  vsprintf( buf, fmt, ap );
+  if( errno == 0 )
+    sprintf( buf + strlen( buf ), "\n" );
+  else
+    sprintf( buf + strlen( buf ), ": %s\n", strerror(errno)); 
+
+  syslog( LOG_ERR, "%s: %s", mode, buf );
+
+  if( status >= 0 ){ exit( status ); }
   return;
 }
 
 /**
- *  joe_warning warn the user but continue to run
+ *  error_message    program centric error message
+ */
+void
+error_message( int status, const char *mode, const char *fmt, va_list ap )
+{
+  char buf[BUFSIZE/2];
+  char msg[BUFSIZE];
+
+  vsprintf( buf, fmt, ap );
+  if( errno == 0 || errno == ENOSYS )
+    snprintf( msg, sizeof( msg ), "%s\n", buf );
+  else
+    snprintf( msg, sizeof( msg ), "%s: %s\n", buf, strerror(errno));
+
+  fflush( stdout );
+  fprintf( stderr, "%s: %s", mode, msg );
+
+  if( status >= 0 ){ exit( status ); }
+  return;
+}
+
+
+/**
+ *  log_warning but continue...
  */
 void 
-joe_warning( const char *fmt, ... )
+log_warning( const char *fmt, ... )
 {
   va_list ap;
   va_start( ap, fmt );
@@ -63,19 +108,52 @@ joe_warning( const char *fmt, ... )
   /** 
    * -1, no exit 
    */
-  error_message( -1, "warning", fmt, ap );
+  log_message( -1, "warning", fmt, ap );
   va_end( ap );
   
   return;
 }
 
-		
+/**
+ *  joe_warning warn the user but continue to run
+ */
+void
+joe_warning( const char *fmt, ... )
+{
+  va_list ap;
+  va_start( ap, fmt );
+
+  /** 
+   * -1, no exit 
+   */
+  error_message( -1, "warning", fmt, ap );
+  va_end( ap );
+
+  return;
+}
+
 /** 
- * joe_error    signal error but continue to run
- * @param         char *
- * @return        void
+ * log_error    signal error but continue to run
  */
 void 
+log_error( const char *fmt, ... )
+{
+  va_list ap;
+  va_start( ap, fmt );
+
+  /** 
+   * -1, no exit 
+   */
+  log_message( -1, "Error", fmt, ap );
+  va_end( ap );
+
+  return;
+}
+
+/** 
+ * joe_error    signal error but continue to run
+ */
+void
 joe_error( const char *fmt, ... )
 {
   va_list ap;
@@ -90,12 +168,30 @@ joe_error( const char *fmt, ... )
   return;
 }
 
+
 /**
- *  joe_fatal   EXIT on fatal condition
- *  @param        char *
- *  @return       void
+ *  log_fatal   EXIT on fatal condition
  */
 void 
+log_fatal( const char *fmt, ... )
+{
+  va_list ap;
+  va_start( ap, fmt );
+
+  /** 
+   * 1, print message and exit 
+   */
+  log_message( 1, "FATAL", fmt, ap );
+  va_end( ap );
+
+  return;
+}
+
+
+/**
+ *  joe_fatal   EXIT on fatal condition
+ */
+void
 joe_fatal( const char *fmt, ... )
 {
   va_list ap;
@@ -109,5 +205,3 @@ joe_fatal( const char *fmt, ... )
 
   return;
 }
-
-
